using LoginPI.Engine.ScriptBase;

public class FileRegistry : ScriptBase
{
    void Execute()
    {
        // ----------- COPYFILE -----------
        // DESCRIPTION
        // CopyFile copies a file from the source to the destination path while overwriting the destination

        // PARAMETER LIST
        // 1: sourcepath defines the file to copy
        // 2: destinationPath defines the destination of the file
        // 3: continueOnError, we can indicate if the engine should keep going with the next set of actions in case of a error. This could be especially helpful with if else statements.
        // 4: overwrite specifies if we overwrite the file, true or false 

        // EXAMPLES
        CopyFile(sourcePath:"C:\\somefile.txt",destinationPath:"D:\\somefile.txt",continueOnError:false,overwrite:true);


        // With update 4.1 it's now possible to download knownfiles from the appliance. The list of knownfiles are:
        // 1: PdfFile. Downloads a LoginVSI pdf file
        // 2: Excelsheet. Downloads a LoginVSI xlsx file
        // 3: OutlookConfiguration. Downloads a LoginVSI PRF file
        // 4: OutlookData. Downloads a LoginVSI PST file
        // 5: PowerPointPresentation. Downloads a LoginVSI pptx file
        // 6: RichTextFile. Downloads a LoginVSI rtf file
        // 7: WordDocument. Downloads a LoginVSI txt file

        CopyFile(KnownFiles.PdfFile, "C:\\Temp\\loginvsi.pdf",continueOnError:false,overwrite:true);

        // ----------- FILEEXISTS -----------
        // DESCRIPTION
        // FileExists checks whether a file exists or not. This is especially useful in an IF statement, for help on IF statements refer to [5.1]IfElse.cs

        //EXAMPLES
        FileExists("C:\\Temp\\loginvsi.pdf");
        

        // ----------- COPYFOLDER -----------
        // DESCRIPTION
        // CopyFolder copies a folder from the source to the destination path while overwriting the destination
        
        // PARAMETER LIST
        // 1: sourcepath defines the folder to copy
        // 2: destinationPath defines the destination of the folder
        // 3: continueOnError, we can indicate if the engine should keep going with the next set of actions in case of a error. This could be especially helpful with if else statements. 

        //EXAMPLES
        CopyFolder(sourcePath:"C:\\somefolder",destinationPath:"D:\\somefolder",continueOnError:false); //  Copy's the source folder to the destinationpath. This will overwrite anything with the same name in the destination


        // ----------- DIRECTORYEXISTS -----------
        // DESCRIPTION
        // DirectoryExists checks whether a directory exists or not. This is especially useful in an IF statement, for help on IF statements refer to [5.1]IfElse.cs

        //EXAMPLES
        DirectoryExists("C:\\Temp");


        // ----------- REMOVEFILE -----------
        // DESCRIPTION
        // RemoveFile removes the specified file

        // PARAMETER LIST
        // 1: path the path to the file to be removed
        // 2: continueOnError, we can indicate if the engine should keep going with the next set of actions in case of an error. This could be especially helpful with if else statements. 

        // EXAMPLES
        RemoveFile(path:"C:\\somefile.txt",continueOnError:false);



        // ----------- REMOVEFOLDER -----------
        // DESCRIPTION
        // RemoveFolder removes the specified folder recursively

        // PARAMETER LIST
        // 1: path the path to the folder to be removed
        // 2: continueOnError, we can indicate if the engine should keep going with the next set of actions in case of an error. This could be especially helpful with if else statements. 

        // EXAMPLES
        RemoveFolder(path:"C:\\somefolder",continueOnError:false);


        // ----------- UNZIPFILE -----------
        // DESCRIPTION
        // UnzipFile unzips a zip file to a sourcedestination

        //PARAMETER LIST
        // 1: sourcePath defines the source zip file
        // 2: destinationFolder defines the destination folder to unzip the contents
        // 3: continueOnError we can indicate if the engine should keep going with the next set of actions in case of an error. This could be especially helpful with if else statements.
        // 4: overWrite specifies if we overwrite files and folders, true or false

        //EXAMPLES
        UnzipFile(sourcePath:"C:\\Temp\\loginvsi.zip", destinationFolder:"C:\\temp\\loginvsiwebsite",continueOnError:false,overWrite:false);    

        // ----------- REGIMPORT -----------
        // DESCRIPTION
        // RegImport uses reg.exe to import a registry file

        // PARAMETER LIST
        // 1: registryFile is the path to the registry file to import
        // 2: continueOnError, we can indicate if the engine should keep going with the next set of actions in case of an error. This could be especially helpful with if else statements. 

        // EXAMPLES
        RegImport(registryFile:"C:\\Registryfile.reg",continueOnError:false);
    }
}