using LoginPI.Engine.ScriptBase;

public class FindControl : ScriptBase
{
    void Execute()
    {
        // ----------- FINDCONTROL -----------
        // DESCRIPTION
        // Each window has a set of controls (buttons, input fields, text fields, etc...)
        // Using FindControl you can find and subsequently interact with these controls
        // START already defines the initial window of the application as the mainWindow variable or you can use FindWindow to find other windows
        // FindControl can use these windows to retrieve information of control within the window
        // the ApplicationXRay.exe in the tools folder can recognize these controls and provide information
        
        // PARAMETER LIST
        // 1: Title, will search for the title if defined.
        // 2: className, will search for the classname if defined
        // 3: Timeout, engine will throw an error after the defined timeout unless continueonerror is set to true
        // 4: SearchRecursively, defines if only the direct childs or also all indirect children of the window should be searched
        // 5: continueOnError, we can indicate if the engine should keep going with the next set of actions in case of a error. This could be especially helpful with if else statements.

        // NOTE: classname and title can contain wildcards (*).

        // EXAMPLES
        var Save = MainWindow.FindControl(title : "Save As");

        // CONTROL ACTION EXAMPLES
        // When the engine finds the control it can perform multiple actions on the control

        Save.Click();               //  This will left click the control.
        Save.DoubleClick();         //  This will doubleclick the control.
        Save.RightClick();          //  This will rightclick the control.
        Save.Focus();               //  Will focus on the control.
        Save.Type("");              //  Type will type directly to the control and keeps the focus on this control

        Save.GetAllChildControls(); // Gets all direct child controls for the window (can also be used on a control)
        Save.GetProcess();          // Gets the processname for the window or control
        Save.GetTitle();            // Gets the title for the window or control
        Save.GetClass();            // Gets the class name for the window or control
        Save.GetBounds();           // Gets the bounds of the found Window (X, Y coordinates and more)
    }
}
