using LoginPI.Engine.ScriptBase;


public class FindWindow : ScriptBase
{
    void Execute()
    {
        // ----------- FINDWINDOW -----------
        // DESCRIPTION
        // FindWindow can be used to detect new windows that have been opened or are already open
        // Each window has a set of information. A class, title and a processname
        // the ApplicationXRay.exe in the tools folder can recognize these controls and provide information

        // PARAMETER LIST
        // 1: Title, will search for the title if defined.
        // 2: className, will search for the classname if defined
        // 3: processName will search for the process name that you fil in. The process name can be detected with our ApplicationXray application. example: notepad
        // 4: Timeout, engine will break after the defined timeout unless continueonerror = true
        // 5: continueOnError, we can indicate if the engine should keep going with the next set of actions in case of a error. This could be especially helpful with if else statements.

        // EXAMPLES
        var OpenDialogue = FindWindow(title:"Open File",timeout:10);

        // CONTROL ACTION EXAMPLES
        // When the engine finds the window it can perform multiple actions on the window 
        OpenDialogue.Maximize();
        OpenDialogue.Minimize();  
        OpenDialogue.Restore();
        OpenDialogue.Focus();
        OpenDialogue.Close(); 
        OpenDialogue.Type("");              //  Type will type directly to the window and keeps the focus

        OpenDialogue.GetAllChildControls(); // Gets all direct child controls for the window (can also be used on a control)
        OpenDialogue.GetProcess();          // Gets the processname for the window or control
        OpenDialogue.GetTitle();            // Gets the title for the window or control
        OpenDialogue.GetClass();            // Gets the class name for the window or control
        OpenDialogue.GetBounds();           // Gets the bounds of the found Window (X, Y coordinates and more)
    }
}