using LoginPI.Engine.ScriptBase;

public class FindComponents : ScriptBase
{
    void Execute()
    {
        // ----------- NAVIGATE -----------
        // DESCRIPTION
        // Navigate, navigates to the specified url, example : https://loginvsi.com

        // PARAMETER LIST
        // 1: url defines which url the browser has to navigate to
        // 2: timerName if specified it will time the navigation action

        // EXAMPLE
        Navigate(url: "https://loginvsi.com", timerName: "Example");

        // ----------- FINDWEBCOMPONENTBYSELECTOR -----------
        // DESCRIPTION
        // FindWebComponentBySelector, Finds a web element based on the given CSS selector
        // FindWebComponentBySelector accepts multiple parameters (the xRay application in the Tools folder in the LoginVSI Toolset can detect these parameters)

        // PARAMETER LIST
        // 1: selector defines which css selector the engine should look for
        // 2: timeout is the maximum amount of seconds the search on the WebComponent can take. After the timeout is reached the engine will throw an error. 
        //    The default timeout is 30 seconds
        // 3: continueOnError is set to false by default

        // EXAMPLES
        FindWebComponentBySelector(selector:"",timeout:30,continueOnError:false);

        // It's also possible to type to the web element via
        FindWebComponentBySelector(selector:"",timeout:30,continueOnError:false).Type("Example text");
        // You can also send a Click to the found web element
        FindWebComponentBySelector(selector:"",timeout:30,continueOnError:false).Click();


        // ----------- FINDALLWEBCOMPONENTSBYSELECTOR -----------
        // DESCRIPTION
        // FindAllWebComponentBySelector, Finds all web elements based on the given CSS selector
        // FindAllWebComponentBySelector accepts multiple parameters (the xRay application in the Tools folder in the LoginVSI Toolset can detect these parameters)
        // In contrast to other commands this command returns an array of objects

        // PARAMETER LIST
        // 1: selector defines which css selector the engine should look for
        // 2: timeout is the maximum amount of seconds the search on the WebComponent can take. After the timeout is reached the engine will throw an error. 
        //    The default timeout is 30 seconds
        FindAllWebComponentsBySelector(selector:"", timeout:30);

    }
}